#*******************************************************************************
# Licensed Materials - Property of IBM
#
# 5724-W86 5724-X63
#
# (C) Copyright IBM Corp. 2003, 2011. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#*******************************************************************************
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#

package EngineConfig;


@ISA = qw(Exporter);
@EXPORT = qw(engine_config);

#use diagnostics;
use strict;
use Exporter ();
use Data::Dumper;


use Date::Calc qw(Decode_Month Add_Delta_YMDHMS);

#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------

my @rules = (
	{
		RULE_TYPE              => 'GENERIC_CSV_GATEWAY',
		RULE_DESC              => 'Parse Cisco GGSN r8 raw data',
		INPUT_FILE_DESCRIPTION => [	'^PassiveCollector-.+\.csv$',	],
		INPUT_DIR_DEPTH        => 1,
		ORDER_OF_FILES         => 'OLDEST_FIRST',
		FIELD_SEPARATOR        => ',',
		DATA_FIELDS                   => [ 0 .. 250 ],
		INVALID_VALUE_MATCH           => [],
		WHITESPACE_MODIFIER           => '_',
		FIELDS_TO_KEY_PIF_FILENAME    => [],
		DEFAULT_NULL_VALUE            => '',
		UPPERCASE_COUNTERS            => 0,
		HEADER_INFO_TO_KEY_PIF_FILENAME   => ['BLOCKNAME'],
		PIF_FILENAME_EXTRACT              => '(PassiveCollector-[^_]+)_\w+_(\d{2}_\d{2}_\d{4}_\d{2}_\d{2}(?:_\d{2})?)\.csv',
		FILENAME_HEADER_FIELDS            =>
                                                {
                                                  BLOCKNAME	=> 'PassiveCollector-[^_]+_(\w+)_\d{2}_\d{2}_\d{4}_\d{2}_\d{2}(?:_\d{2})?\.csv',
                                                  FILENAME      => '(PassiveCollector-[^_]+_\w+_(\d{2}_\d{2}_\d{4}_\d{2}_\d{2}(?:_\d{2})?)\.csv)',
												  RAW_TIME      => 'PassiveCollector-[^_]+_\w+_\d{2}_\d{2}_\d{4}_(\d{2}_\d{2})(?:_\d{2})?\.csv',
                                                },
		HEADER_DATA_RECORD_PROCESSING => sub {
			my ( $blk_name_ref, $h_ref, $d_ref ) = @_;

			# Set block name
			$$blk_name_ref = $h_ref->{BLOCKNAME};
			
			$d_ref->{filename}= $h_ref->{FILENAME};
			
			# change the value of systemIPAddress and systemName if it is null 
			 if ($d_ref->{systemIPAddress} eq '') {
				$d_ref->{systemIPAddress} = 'N/A';
			 } elsif ($d_ref->{systemName} eq '') {
				$d_ref->{systemName} = 'N/A';
			 }
         
			# change/populate the indexes or key accordingly
			 if (($h_ref->{BLOCKNAME} eq "cgprsAccPt") || ($h_ref->{BLOCKNAME} eq "cgprsAccPtStatistics")) {
				   $d_ref->{'cgprsAccPtIndex'} = $d_ref->{'index'};
			 }
         
			 if ($h_ref->{BLOCKNAME} eq "cpmCPUTotal") {
				   $d_ref->{'cpmCPUTotalIndex'} = $d_ref->{'index'};
			 }
         
			 if ($h_ref->{BLOCKNAME} eq "ccsBMA") {
				   my @bmaData = split /\./,$d_ref->{'index'};
					$d_ref->{'entPhysicalIndex'} = @bmaData[0];
					
					my $countName = @bmaData[1];
					
					for(my $position=0; $position < $countName; $position++)
					{
					  $d_ref->{'ccsBMAVrfName'} = $d_ref->{'ccsBMAVrfName'} . '.' . @bmaData[($position+2)]
					}
					
					# split the string into an array of characters
					my @array = split /\./,$d_ref->{'ccsBMAVrfName'};
					$d_ref->{'ccsBMAVrfName'} = pack("C*", @array);
					$d_ref->{'ccsBMAVrfName'} =~ s/[^\x20-\x7E]//g;
					
					$d_ref->{'ccsBMAIpAddrType'} = @bmaData[($countName + 2)];
			
					my $countIP = @bmaData[($countName + 3)];
					
					
					for(my $position=0; $position < $countIP; $position++)
					{
					  if ($position > 0)
					  {
						 $d_ref->{'ccsBMAIpAddr'} = $d_ref->{'ccsBMAIpAddr'} . '.' . @bmaData[($position+$countName + 4)];
					  }
					  else
					  {
						 $d_ref->{'ccsBMAIpAddr'} = @bmaData[($position+$countName + 4)];
					  }
					}
					
					$d_ref->{'ccsBMAPort'} = @bmaData[scalar (@bmaData - 1)];
			 }
         
			 if ($h_ref->{BLOCKNAME} eq "ccsQuotaMgr") {
				   my @bmaData = split /\./,$d_ref->{'index'};
					$d_ref->{'entPhysicalIndex'} = @bmaData[0];
					
					my $countName = @bmaData[1];
					
					for(my $position=0; $position < $countName; $position++)
					{
					  $d_ref->{'ccsQuotaMgrVrfName'} = $d_ref->{'ccsQuotaMgrVrfName'} . '.' . @bmaData[($position+2)]
					}

					# split the string into an array of characters
					my @array = split /\./,$d_ref->{'ccsQuotaMgrVrfName'};
					$d_ref->{'ccsQuotaMgrVrfName'} = pack("C*", @array);
					$d_ref->{'ccsQuotaMgrVrfName'} =~ s/[^\x20-\x7E]//g;
					
					$d_ref->{'ccsQuotaMgrIpAddrType'} = @bmaData[($countName + 2)];
			
					my $countIP = @bmaData[($countName + 3)];
					
					for(my $position=0; $position < $countIP; $position++)
					{
					  if ($position > 0)
					  {
						 $d_ref->{'ccsQuotaMgrIpAddr'} = $d_ref->{'ccsQuotaMgrIpAddr'} . '.' . @bmaData[($position+$countName + 4)];
					  }
					  else
					  {
						 $d_ref->{'ccsQuotaMgrIpAddr'} = @bmaData[($position+$countName + 4)];
					  }
					}
					
					$d_ref->{'ccsQuotaMgrPort'} = @bmaData[scalar (@bmaData - 1)];
			 }
			 
			 if ($h_ref->{BLOCKNAME} eq "cGtpPathStatistics") {
				   my @bmaData = split /\./,$d_ref->{'index'};
			   $d_ref->{'cGtpPathAddressType'} = @bmaData[0];
			
				   my $countIP = @bmaData[1];
					
				   for(my $position=0; $position < $countIP; $position++)
				   {
					 if ($position > 0)
					 {
						$d_ref->{'cGtpPathAddress'} = $d_ref->{'cGtpPathAddress'} . '.' . @bmaData[($position+2)];
					 }
					 else
					 {
						$d_ref->{'cGtpPathAddress'} = @bmaData[($position+2)];
					 }
				   }
				   
				   $d_ref->{'cGtpPathPort'} = @bmaData[scalar (@bmaData - 1)];
			 }
         
			 if ($h_ref->{BLOCKNAME} eq "cGtpPathStatisticsHistory") {
				   my @bmaData = split /\./,$d_ref->{'index'};
				   $d_ref->{'cGtpHistIndex'} = @bmaData[0];

				   $d_ref->{'cGtpHistRemoteAddrType'} = @bmaData[1];
				   
				   my $countIP = @bmaData[2];
				   
				   for(my $position=0; $position < $countIP; $position++)
				   {
					 if ($position > 0)
					 {
						$d_ref->{'cGtpHistRemoteAddress'} = $d_ref->{'cGtpHistRemoteAddress'} . '.' . @bmaData[($position+3)];
					 }
					 else
					 {
						$d_ref->{'cGtpHistRemoteAddress'} = @bmaData[($position+3)];
					 }
				   }
				   
				   $d_ref->{'cGtpHistRemotePort'} = @bmaData[scalar (@bmaData - 1)];
			 }
			 
			 if ($h_ref->{BLOCKNAME} eq "cpmCPUThreshold") {
				   my @bmaData = split /\./,$d_ref->{'index'};
				   $d_ref->{'cpmCPUTotalIndex'} = @bmaData[0];
				   $d_ref->{'cpmCPUThresholdClass'} = @bmaData[1];
			 }
			 
			return 0;
		},
	},
);

sub engine_config {
    return \@rules;
}

1;
