#*******************************************************************************
# Licensed Materials - Property of IBM
#
# 5724-W86 5724-X63
#
# (C) Copyright IBM Corp. 2003, 2011. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#*******************************************************************************
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file, DON'T TOUCH IT.
#
#

package UserConfig;

@ISA = qw(Exporter);
@EXPORT = qw(postparser_config);

use strict;
use warnings;
use Exporter ();


#-------------------------------------------------------------------------------


my @rules =
(
#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------

	{
	    RULE_TYPE => 'PERLIZE',
	    RULE_DESC => 'Round the time to the nearest period',
	    INPUT_FILE_DESCRIPTION => ['^PassiveCollector-.+-#-I\.pif$',],
	    HEADER_COUNTERS_OP => sub
	    {
	    },
	    DATA_COUNTERS_OP => sub
	    {
			my $c_ref = shift ;    
		
			 # Store the original startTime and endTime
			 $c_ref->{myStartTime} = $c_ref->{startTime};
			 $c_ref->{myEndTime}  = $c_ref->{endTime};
		 
			 # Round the time to the nearest minute
			 my $startTime = $c_ref->{startTime};
			 my $endTime = $c_ref->{endTime};
			 $c_ref->{startTime} = RoundingtoMinute($startTime);
			 $c_ref->{endTime} = RoundingtoMinute($endTime);

			return 0 ;
	    },
	    FILENAME_SUFFIX   => 'PZ',
	    REDUNDANT_DATA_COUNTERS => [],
	    REDUNDANT_HEADER_COUNTERS => [],
	    PRODUCE_PIF => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},

	#-----------------------------------------------------------------------
	# SPLIT the files according to their startTime and endTime
	#-----------------------------------------------------------------------
	
	# Split data to separate the PIF based on startTime and endTime
	{
		RULE_TYPE => 'FILE_SPLIT',
		RULE_DESC => "Splitting large files into smaller files",
		INPUT_FILE_DESCRIPTION => ['^PassiveCollector-.+-(cgprsAccPt|cgprsAccPtStatistics)-#-I-#-PZ\.pif$',],
		
		COUNTERS_USED_TO_SPLIT_FILE => {
			day => '(.*)',
			startTime => '(.*)',
			endTime => '(.*)',
		},
		SPLIT_COUNTERS_ORDER => [ qw(day startTime endTime) ],
		PRODUCE_PIF => 'True',
		PRODUCE_LIF => 0,
		REDUNDANT_DATA_COUNTERS => [],
	},
	
	{
		RULE_TYPE => 'COPY_HEADER_N_BODY_COUNTERS',
		RULE_DESC => 'move counters from body to header for startTime and endTime',
		INPUT_FILE_DESCRIPTION => [ 
			'^PassiveCollector-.+-#-FS\.pif$', 
		],
		COPY_HEADER_COUNTERS_2_BODY => [ ],
		COPY_BODY_COUNTERS_2_HEADER => [ 'startTime', 'endTime', 'day'],
		REDUNDANT_HEADER_COUNTERS => [ ],
		REDUNDANT_BODY_COUNTERS => [ ],
		PRODUCE_PIF => 'True',
		OUTPUT_FORMAT => 0,
	},
	
	#-----------------------------------------------------------------------
	# JOIN the files according to their day, startTime and endTime
	#-----------------------------------------------------------------------
	
	# Join data for block, cgprsAccPt
	{
		RULE_TYPE => 'JOIN',
		RULE_DESC => 'Join all data for block, cgprsAccPt',
		INPUT_FILE_DESCRIPTION  => [
			'^PassiveCollector-.+(-#-cgprsAccPt-#-.+-#-FS-#-CC)\.pif$',	#alm00219045
			'^PassiveCollector-.+(-#-cgprsAccPt-#-.+-#-FS-#-CC)\.pif$',	#alm00219045
		],
		COUNTERS_TO_JOIN_ON => [ qw(filename myStartTime myEndTime index cgprsAccPtIndex systemIPAddress systemName) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => 1,
		OUTPUT_BLOCK_NAME => 'cgprsAccPt',
		OUTPUT_FILENAME_START => 'CiscoGGSN_R080',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(BLOCKNAME day startTime endTime RAW_TIME) ],
		PRODUCE_PIF => 'True',
		REDUNDANT_HEADER_COUNTERS => [ 'FILENAME' ], 
		REDUNDANT_DATA_COUNTERS => [ 'startTime', 'endTime', 'filename', 'day', 'myStartTime', 'myEndTime' ],
	},
	
	# Join data for block, cgprsAccPtStatistics
	{
		RULE_TYPE => 'JOIN',
		RULE_DESC => 'Join all data for block, cgprsAccPtStatistics',
		INPUT_FILE_DESCRIPTION  => [
			'^PassiveCollector-.+(-#-cgprsAccPtStatistics-#-.+-#-FS-#-CC)\.pif$',	#alm00219045
			'^PassiveCollector-.+(-#-cgprsAccPtStatistics-#-.+-#-FS-#-CC)\.pif$',	#alm00219045
		],
		COUNTERS_TO_JOIN_ON => [ qw(filename myStartTime myEndTime index cgprsAccPtIndex systemIPAddress systemName) ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => 1,
		OUTPUT_BLOCK_NAME => 'cgprsAccPtStatistics',
		OUTPUT_FILENAME_START => 'CiscoGGSN_R080',
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => [ qw(BLOCKNAME day startTime endTime RAW_TIME) ],
		PRODUCE_PIF => 'True',
		REDUNDANT_HEADER_COUNTERS => [ 'FILENAME' ], 
		REDUNDANT_DATA_COUNTERS => [ 'startTime', 'endTime', 'filename', 'day', 'myStartTime', 'myEndTime' ],
	},
	
	# Aggregate data for block, cgprsAccPt_APN
	{
		RULE_TYPE => 'ACCUMULATE',
		RULE_DESC => 'Aggregate data for block, cgprsAccPt_APN',
		OUTPUT_BLOCK_NAME => 'cgprsAccPt_APN',
		INPUT_FILE_DESCRIPTION => [
		    '^CiscoGGSN_R080-#-cgprsAccPt-#-.+-#-J\.pif$',
		],
		COUNTERS_TO_SORT_ON => [ 'cgprsAccPtIndex' ],
		NON_ADDITIVE_COUNTERS => [ 'cgprsAccPtIndex' ],
		MAXIMUM_COUNTERS => [qw(cgprsAccPtIdlePdpPurgeTimer cgprsAccPtPppRegenMaxSessions cgprsAccPtPppRegenSetupTime)],
		MAXIMUM_APPEND_STR => "_MAX",
		MAXIMUM_NO_APPEND_STR => [qw(cgprsAccPtIdlePdpPurgeTimer cgprsAccPtPppRegenMaxSessions cgprsAccPtPppRegenSetupTime)],
		AVERAGE_COUNTERS => [qw(cgprsAccPtIpAddrAllocations cgprsAccPtUsers)],
		AVERAGE_APPEND_STR => "_AVG",

		REDUNDANT_DATA_COUNTERS => [ 'systemName' ],
		REDUNDANT_HEADER_COUNTERS => [],
		PRODUCE_PIF => 'True',
	},
	
	# Aggregate data for block, cgprsAccPtStatistics_APN
	{
		RULE_TYPE => 'ACCUMULATE',
		RULE_DESC => 'Aggregate data for block, cgprsAccPtStatistics_APN',
		OUTPUT_BLOCK_NAME => 'cgprsAccPtStatistics_APN',
		INPUT_FILE_DESCRIPTION => [
		    '^CiscoGGSN_R080-#-cgprsAccPtStatistics-#-.+-#-J\.pif$',
		],
		COUNTERS_TO_SORT_ON => [ qw(cgprsAccPtIndex) ],
		NON_ADDITIVE_COUNTERS => [ qw(cgprsAccPtIndex) ],
		#AVERAGE_COUNTERS => [qw(cgprsAccPtActivePdps)],	#comment for MR1116104410
		#AVERAGE_APPEND_STR => "_AVG",	#comment for MR1116104410

		REDUNDANT_DATA_COUNTERS => [ 'systemName' ],
		REDUNDANT_HEADER_COUNTERS => [],
		PRODUCE_PIF => 'True',
	},


	#-----------------------------------------------------------------------
	# Perlize the counters accordingly
	#-----------------------------------------------------------------------
	
	# Perlize rule to map the counters for cgprsAccPt_APN
	{
	    RULE_TYPE => 'PERLIZE',
	    RULE_DESC => 'Create Adapter KPIs for block, cgprsAccPt_APN',
	    INPUT_FILE_DESCRIPTION => [
		'^CiscoGGSN_R080-#-cgprsAccPt-#-.+-#-J-#-cgprsAccPt_APN-#-A\.pif$',
	    ],
	    HEADER_COUNTERS_OP => sub
	    {
		my $h_ref = shift ;
		$h_ref->{'BLOCKNAME'} = 'cgprsAccPt_APN';
		
		return 0 ;
	    },
	    DATA_COUNTERS_OP => sub
	    {
		my $c_ref = shift ;    
		
		$c_ref->{'cgprsAccPtIpAddrAllocations'} = int(0.5 + $c_ref->{'cgprsAccPtIpAddrAllocations_AVG'});
		$c_ref->{'cgprsAccPtUsers'} = int(0.5 + $c_ref->{'cgprsAccPtUsers_AVG'});
		
		return 0 ;
	    },
	    FILENAME_SUFFIX   => 'PZ',
	    REDUNDANT_DATA_COUNTERS => [ qw(index cgprsAccPt_APN_NUM_IN_SUM cgprsAccPtIpAddrAllocations_AVG cgprsAccPtUsers_AVG) ],
	    REDUNDANT_HEADER_COUNTERS => [],
	    PRODUCE_PIF => 'True',
	    OUTPUT_FORMAT => 'LIF_Writer',
	},
	
	# Perlize rule to map the counters for cgprsAccPtStatistics_APN
	{
	    RULE_TYPE => 'PERLIZE',
	    RULE_DESC => 'Create Adapter KPIs for block, cgprsAccPtStatistics_APN',
	    INPUT_FILE_DESCRIPTION => [
		'^CiscoGGSN_R080-#-cgprsAccPtStatistics-#-.+-#-J-#-cgprsAccPtStatistics_APN-#-A\.pif$',
	    ],
	    HEADER_COUNTERS_OP => sub
	    {
		my $h_ref = shift ;
		$h_ref->{'BLOCKNAME'} = 'cgprsAccPtStatistics_APN';
		
		return 0 ;
	    },
		#comment for MR1116104410
	    # DATA_COUNTERS_OP => sub
	    # {
		# my $c_ref = shift ;    
		
		
		# $c_ref->{'cgprsAccPtActivePdps'} = int(0.5 + $c_ref->{'cgprsAccPtActivePdps_AVG'});
		
		# return 0 ;
	    # },
	    FILENAME_SUFFIX   => 'PZ',
	    REDUNDANT_DATA_COUNTERS => [ qw(index cgprsAccPtStatistics_APN_NUM_IN_SUM cgprsAccPtActivePdps_AVG) ],
	    REDUNDANT_HEADER_COUNTERS => [],
	    PRODUCE_PIF => 'True',
	    OUTPUT_FORMAT => 'LIF_Writer',
	},

#-------------------------------------------------------------------------------
# End of rule
#-------------------------------------------------------------------------------
);

sub postparser_config {
	return \@rules;
}

sub RoundingtoMinute()
{
	my $time = shift;		
	my $temp = $time % 3600;	
	my $to_be_subtracted = $temp % 60;
	$time = $time - $to_be_subtracted;

	return $time;
}

1;
